@@ -5,7 +5,7 @@ from zodipy._components import Component, Cloud, Band, Ring, Feature
 
 
 class ComponentLabel(Enum):
-    """Labels representing the six Zodiacal components in the K98 IPD model."""
+    """Labels representing the six Zodiacal components in the K98 model."""
 
     CLOUD = "cloud"
     BAND1 = "band1"
