@@ -3,6 +3,3 @@ class ModelNotFoundError(Exception):
 
 class SimulationStrategyNotFoundError(Exception):
     """Raised if a non implemented simulation stategy is selected."""
-
-class TargetNotSupportedError(Exception):
-    """Raised when a target that is not supported is selected."""
