@@ -3,12 +3,12 @@ from typing import Protocol
 import numpy as np
 
 
-class ZodiacalComponentEmissionFunc(Protocol):
+class EmissionFunction(Protocol):
     def __call__(
         self,
         distance_to_shell: np.ndarray,
-        observer_coordinates: np.ndarray,
-        earth_coordinates: np.ndarray,
+        observer_position: np.ndarray,
+        earth_position: np.ndarray,
         unit_vectors: np.ndarray,
         freq: float,
     ) -> np.ndarray:
@@ -16,27 +16,28 @@ class ZodiacalComponentEmissionFunc(Protocol):
 
 
 def line_of_sight_integrate(
-    line_of_sight: np.ndarray,
-    get_emission_func: ZodiacalComponentEmissionFunc,
-    observer_coordinates: np.ndarray,
-    earth_coordinates: np.ndarray,
+    radial_distances: np.ndarray,
+    get_emission_func: EmissionFunction,
+    observer_position: np.ndarray,
+    earth_position: np.ndarray,
     unit_vectors: np.ndarray,
     freq: float,
 ) -> np.ndarray:
-    """Integrates the emission for a component using the trapezoidal method.
+    """Returns the integrated Zodiacal emission for a component (Trapezoidal).
 
     Parameters
     ----------
-    line_of_sight
-        Line-of-sight array.
+    radial_distances
+        Array of discrete radial distances from the observer [AU].
     get_emission_func
         The `get_emission` function of the component.
-    observer_coordinates
-        The heliocentric coordinates of the observer.
-    earth_cooridnates
-        The heliocentric coordinates of the Earth.
+    observer_position
+        The heliocentric ecliptic cartesian position of the observer.
+    earth_position
+        The heliocentric ecliptic cartesian position of the Earth.
     unit_vectors
-        Unit vectors pointing to each pixel in the HEALPIX map.
+        Heliocentric ecliptic cartesian unit vectors pointing to each 
+        position in space we that we consider.    
     freq
         Frequency at which to evaluate to Zodiacal Emission.
 
@@ -44,24 +45,24 @@ def line_of_sight_integrate(
     -------
     integrated_emission
         The line-of-sight integrated emission of the shells around an observer
-        for a single Zodiacal Component.
+        for a Zodiacal Component.
     """
 
     emission_previous = get_emission_func(
-        distance_to_shell=line_of_sight[0],
-        observer_coordinates=observer_coordinates,
-        earth_coordinates=earth_coordinates,
+        distance_to_shell=radial_distances[0],
+        observer_position=observer_position,
+        earth_position=earth_position,
         unit_vectors=unit_vectors,
         freq=freq,
     )
-    dR = np.diff(line_of_sight)
+    dR = np.diff(radial_distances)
 
     integrated_emission = np.zeros(unit_vectors.shape[-1])
-    for r, dr in zip(line_of_sight, dR):
+    for r, dr in zip(radial_distances, dR):
         emission_current = get_emission_func(
             distance_to_shell=r,
-            observer_coordinates=observer_coordinates,
-            earth_coordinates=earth_coordinates,
+            observer_position=observer_position,
+            earth_position=earth_position,
             unit_vectors=unit_vectors,
             freq=freq,
         )
